pub struct View {
pub fragment: Fragment,
pub render: RenderOutput,
pub tex: String,
pub warnings: Vec<Diagnostic>,
}Expand description
A typeset editor state with the geometry to paint over it.
Fields
fragment: FragmentThe laid out source.
render: RenderOutputCaret, selection, placeholders, menu anchor and host box placements over fragment.
tex: StringThe LaTeX that was typeset, with placeholders in empty slots.
warnings: Vec<Diagnostic>Warnings TeX and the host boxes raised.