pub struct RenderCache { /* private fields */ }Expand description
Typesets an editor once per revision and keeps the geometry until the caret state changes.
Implementations
Sourceimpl RenderCache
impl RenderCache
Sourcepub fn invalidate(&mut self)
pub fn invalidate(&mut self)
Forget everything, for a change the revision does not show such as a host box size or another editor.
Sourcepub fn view<L: FontLoader>(
&mut self,
editor: &Editor,
typesetter: &mut Typesetter<L>,
mode: MathMode,
boxes: &dyn HostBoxes,
) -> Result<&View, TypesetError>
pub fn view<L: FontLoader>( &mut self, editor: &Editor, typesetter: &mut Typesetter<L>, mode: MathMode, boxes: &dyn HostBoxes, ) -> Result<&View, TypesetError>
The view of editor, typesetting only when its revision changed since the last call.
Sourcepub fn hit_test<L: FontLoader>(
&mut self,
editor: &Editor,
typesetter: &mut Typesetter<L>,
mode: MathMode,
boxes: &dyn HostBoxes,
at: Point,
) -> Result<Option<CaretPath>, TypesetError>
pub fn hit_test<L: FontLoader>( &mut self, editor: &Editor, typesetter: &mut Typesetter<L>, mode: MathMode, boxes: &dyn HostBoxes, at: Point, ) -> Result<Option<CaretPath>, TypesetError>
The caret under at, in the coordinates of View::render.